<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>mxtools</name>
    <message>
        <location filename="../mxtools.ui" line="14"/>
        <location filename="../mxtools.cpp" line="364"/>
        <source>MX Tools</source>
        <translation>MX Ferramentas</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="47"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="50"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="58"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="116"/>
        <source>Close application</source>
        <translation>Fechar a aplicação</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="119"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="127"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="149"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="248"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation>Estas aplicações do MX poupam tempo e esforço na execução de tarefas importantes.</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="264"/>
        <source>Hide individual tools from the menu</source>
        <translation>Ocultar ferramentas do menu, individualmente</translation>
    </message>
    <message>
        <location filename="../mxtools.ui" line="283"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="363"/>
        <source>About MX Tools</source>
        <translation>Sobre o MX Ferramentas </translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="364"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="366"/>
        <source>Configuration Tools for MX Linux</source>
        <translation>Ferramentas de configuração do MX</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="367"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="368"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="369"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="370"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxtools.cpp" line="385"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>
